<?php
/**
 * Minimal Magazine functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package minimal-magazine
 * @author  Towhid, Atlantis Themes
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU Public License
 */

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */

if ( ! function_exists( 'minimal_magazine_setup' ) ) :

function minimal_magazine_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Minimal Magazine, use a find and replace
	 * to change 'minimal-magazine' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'minimal-magazine' );

	/*
     * Add default posts and comments RSS feed links to head.
     */
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );
	add_image_size( 'minimal-mag-magazine-thumb', 820, 400 );
	add_image_size( 'minimal-mag-home-articles', 340, 408 );
    add_image_size( 'minimal-mag-article-thumb', 229, 320, array( 'center', 'center' ) );
	add_image_size( 'minimal-mag-slider', 500, 640 );
    add_image_size( 'minimal-mag-slider-wide', 1650, 625 );
	add_image_size( 'minimal-mag-small', 360, 360, true  );
	set_post_thumbnail_size( 'minimal-mag-magazine-thumb', 820, 400 );

	/*
     * This theme uses wp_nav_menu() in the following locations.
     */
	register_nav_menus( array(
		'primary' 	=> esc_html__( 'Primary Menu', 'minimal-magazine' ),
		'footer' 	=> esc_html__( 'Footer Menu', 'minimal-magazine' ),
	) );

	// Add theme support for Custom Logo.
	add_theme_support( 'custom-logo');
	/*
	 * Switch default core yorkup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array('search-form','comment-form','comment-list','gallery','caption',) );

	add_theme_support('widget-customizer');

    /*
     * Enable support for Customizer Selective Refresh.
     * See: https://make.wordpress.org/core/2016/02/16/selective-refresh-in-the-customizer/
     */
	add_theme_support( 'customize-selective-refresh-widgets' );

	add_theme_support( 'custom-background', apply_filters( 'minimal_custom_background_args', array(
		'default-color' => '#eceef1',
		'default-image' => '',
	) ) );

    // Gutenberg editor support.
    add_theme_support( 'editor-color-palette', '#cc4a00', '#252525', '#2d2d2d', '#ffffff' );

    add_theme_support( 'gutenberg',
        array(
            'colors' => array( '#cc4a00', '#252525', '#2d2d2d', '#ffffff' ),
        )
    );


	// Set the default content width.
	$GLOBALS['content_width'] = apply_filters( 'minimal_content_width', 640 );

	add_editor_style();

    // Define and register starter content to showcase the theme on new sites.
    $starter_content = array(

        'posts' => array(
            'home' => array(
                    'post_title'   => esc_attr__( 'Welcome', 'minimal-magazine' ),
                    'post_content' => __( 'This is your homepage which is what most visitors will see when they first visit your website.You can change this text by editing the "Welcome" page via the "Pages" menu in your dashboard.', 'minimal-magazine' ),
                    'template'     => 'template-homepage.php',
            ),
            'about' => array(
                    'post_type'     => 'page',
                    'post_title'    => __( 'About', 'minimal-magazine' ),
                    'post_content'  => __( 'You might be an artist who would like to introduce yourself and your work here or maybe you&rsquo;re a business with a mission to describe.', 'minimal-magazine' ),
            ),
            'contact' => array(
                    'post_type'     => 'page',
                    'post_title'    => __( 'Contact', 'minimal-magazine' ),
                    'post_content'  => __( 'This is a page with some basic contact information, such as an address and phone number. You might also try a plugin to add a contact form.', 'minimal-magazine' ),
            ),
            'blog',
            'coffees' => array(
                    'post_type'     => 'post',
                    'post_title'    => __( 'Contact', 'minimal-magazine' ),
                    'post_content'  => __( 'This is a post with some basic contact information, such as an address and phone number. You might also try a plugin to add a contact form.', 'minimal-magazine' ),
            ),
        ),


        // Default to a static front page and assign the front and posts pages.
        'options' => array(
            'show_on_front'     => 'page',
            'page_on_front'     => '{{home}}',
            'page_for_posts'    => '{{blog}}',
            'blogname'          => 'Minimal Magazine',
            'blogdescription'   => 'Minimal Magazine Demo site',
        ),

        // Set the front page section theme mods.
        'theme_mods' => array(
            'home_latest_article_layout'                => 4,
            'home_latest_article_box_color'             => '#FFFFFF',
            'home_latest_article_background_color'      => '#FFFFFF',
            'minimal_featured_article_title_position'   => 'title-center',
            'home_featured_article_layout_selector'     => 2,
            'home_featured_article_box_color'           => '#FFFFFF',
            'home_featured_article_background_color'    => '#FFFFFF',
            'home_article_by_category_title_position'   => 'title-center',
            'home_article_by_category_layout'           => 2,
            'home_article_by_category_box_color'        => '#FFFFFF',
            'home_article_by_category_background_color' => '#FFFFFF',
            'minimal_home_blogposts_title_position'     => 'title-center',
            'minimal_home_blogposts_layout'             => 1,
            'minimal_blogposts_background_color'        => '#FFFFFF',
            'blog_front_post_per_page_select'           => 6,
            'minimal_canvas_width'                      => '1200px',
            'minimal_header_width'                      => '1200px',
            'body_h1_size'                              => '36px',
        ),

        // Set up nav menus for each of the two areas registered in the theme.
        'nav_menus' => array(
            // Assign a menu to the "primary" location.
            'primary' => array(
                'name' => __( 'Top Menu', 'minimal-magazine' ),
                'items' => array(
                            'page_about' => array(
                                    'type'      => 'post_type',
                                    'object'    => 'page',
                                    'object_id' => '{{about}}',
                            ),
                            'page_contact' => array(
                                    'type'      => 'post_type',
                                    'object'    => 'page',
                                    'object_id' => '{{contact}}',
                            ),
                        ),
            ),

            // Assign a menu to the "footer" location.
            'footer' => array(
                'name' => __( 'Footer Menu', 'minimal-magazine' ),
                'items' => array(
                            'page_about' => array(
                                    'type'      => 'post_type',
                                    'object'    => 'page',
                                    'object_id' => '{{about}}',
                            ),
                            'page_contact' => array(
                                    'type'      => 'post_type',
                                    'object'    => 'page',
                                    'object_id' => '{{contact}}',
                            ),
                        ),
            ),
        ),
    );

    /**
     * Filters Minimal Magazine array of starter content.
     *
     * @since Minimal Magazine
     *
     * @param array $starter_content Array of starter content.
     */
    $starter_content = apply_filters( 'minimalmag_starter_content', $starter_content );

    add_theme_support( 'starter-content', $starter_content );

}

endif;

/**
 * Enqueue scripts and styles.
 */
if ( ! function_exists( 'minimal_scripts' ) ) :

	function minimal_scripts() {
		wp_enqueue_style(	'third-party-libraries',get_template_directory_uri(). '/inc/css/libraries.min.css');
		wp_enqueue_style(	'minimal-stylesheet', get_stylesheet_uri(), array(), '20161022', 'all' );
	  	wp_enqueue_script(	'minimal-js', get_template_directory_uri() . '/inc/js/minimal-app.js',  array('jquery'), '20180108', true );
        wp_enqueue_style( 'minimal-fonts', minimalmag_fonts_url(), array(), null );

	  // Load the html5 shiv.
		wp_enqueue_script( 'minimal-html5', get_template_directory_uri() . '/inc/js/html5.js', array(), '3.7.3' );
		wp_script_add_data( 'minimal-html5', 'conditional', 'lt IE 9' );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
	}

endif;

require_once( get_template_directory() . '/core-functions/core-default.php');
require_once( get_template_directory() . '/core-functions/core-helpers.php');
require_once( get_template_directory() . '/core-functions/core-sidebar.php');
require_once( get_template_directory() . '/core-functions/core-styleclass.php');
require_once( get_template_directory() . '/core-functions/core-header.php');
require_once( get_template_directory() . '/core-functions/core-home.php');
require_once( get_template_directory() . '/core-functions/core-comment.php');
require_once( get_template_directory() . '/core-functions/core-hook.php');
require_once( get_template_directory() . '/inc/custom-header.php');
require_once( get_template_directory() . '/inc/customizer.php');
require_once( get_template_directory() . '/inc/customize/customizer-choices.php');
require_once( get_template_directory() . '/inc/customize/customizer-sanitization.php');

/*
-------------------------------------------------------------------------------------------------------
  Article Author Box
-------------------------------------------------------------------------------------------------------
*/
if ( ! function_exists( 'minimal_get_single_article_author_box' ) ) :

    function minimal_get_single_article_author_box(){

        $avatar             = get_avatar( get_the_author_meta( 'user_email' ), 140 );
        $author_name        = get_the_author();
        $author_bio         = get_the_author_meta( 'description' );
        $author_post_url    = esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) );
        ?>

    <div class="article-author-box">
        <div class="row">
            <div class="col-3">
                <div class="author-box-profile">
                <div class="author-image"><?php echo wp_kses_post($avatar);?></div>
                </div>
            </div>
            <div class="col-9">
                <div class="author-box-text">
                <span class="meta author-posted"><?php echo esc_html__( 'About the Author', 'minimal-magazine' );?></span>
                <span class="author-name heading-three"><?php echo esc_attr($author_name);?></span>
                <span class="meta author-bio"><?php echo esc_attr($author_bio);?></span>
                <span class="meta author-article-link">
                    <a href="<?php echo esc_url($author_post_url);?>"><?php echo esc_html__( 'Read more articles by ', 'minimal-magazine' );?><?php echo esc_attr($author_name);?></a>
                </span>
                </div>
            </div>

        </div>
    </div>

        <?php
    }
endif;



/**
 * Displays the navigation to next/previous post, when applicable.
 *
 * @param array $args Optional. See get_the_post_navigation() for available arguments.
 *                    Default empty array.
 */
function minimal_the_post_navigation( $args = array() ) {
    echo wp_kses_post(minimal_get_the_post_navigation( $args ));
}

/**
 * Retrieves the navigation to next/previous post, when applicable.
 *
 * @param array $args {
 *     Optional. Default post navigation arguments. Default empty array.
 *
 * @type string $prev_text Anchor text to display in the previous post link. Default '%title'.
 * @type string $next_text Anchor text to display in the next post link. Default '%title'.
 * @type bool $in_same_term Whether link should be in a same taxonomy term. Default false.
 * @type array|string $excluded_terms Array or comma-separated list of excluded term IDs. Default empty.
 * @type string $taxonomy Taxonomy, if `$in_same_term` is true. Default 'category'.
 * @type string $screen_reader_text Screen reader text for nav element. Default 'Post navigation'.
 * }
 * @return string Markup for post links.
 */
function minimal_get_the_post_navigation( $args = array() ) {
    $args = wp_parse_args( $args, array(
        'prev_text'          => '%title',
        'next_text'          => '%title',
        'in_same_term'       => false,
        'excluded_terms'     => '',
        'taxonomy'           => 'category',
        'screen_reader_text' => __( 'Post navigation', 'minimal-magazine' ),
    ) );

    $navigation = '';

    $previous = get_previous_post_link(
        '<div class="nav-previous"><span class="nav-previous-title">%link</span>' . '<span class="nav-previous-info">' . __( 'Previous', 'minimal-magazine' ) . '</span></div>',
        $args['prev_text'],
        $args['in_same_term'],
        $args['excluded_terms'],
        $args['taxonomy']
    );

    $next = get_next_post_link(
        '<div class="nav-next"><span class="nav-next-title">%link</span>' . '<span class="nav-next-info">' . __( 'Next', 'minimal-magazine' ) . '</span></div>',
        $args['next_text'],
        $args['in_same_term'],
        $args['excluded_terms'],
        $args['taxonomy']
    );

    // Only add markup if there's somewhere to navigate to.
    if ( $previous || $next ) {
        $navigation = _navigation_markup( $previous . $next, 'post-navigation', $args['screen_reader_text'] );
    }

    return $navigation;
}



/*
-------------------------------------------------------------------------------------------------------
    Category Dropdown Menu
-------------------------------------------------------------------------------------------------------
*/

if ( ! function_exists( 'minimal_category_menu' ) ) :
    function minimal_category_menu(){

    ?>
    <div class="outer-section-category-container">
        <div class="label-container">
            <span>
                <p><?php esc_html_e( 'Topics', 'minimal-magazine' ); ?></p>
                <i class="cat-icon ion-chevron-down" style="display: inline-block;"></i>
            </span>
        </div>

        <div class="inner-section-category-container">
        <div class="section section-site-category">
        <div class="site-category-container">
        <ul class="category-wrapper">
        <?php

            $categories = get_categories( array(
            'orderby' => 'name',
            'order'   => 'ASC'
        ) );

        foreach( $categories as $category ) {

            $category_link = esc_url( get_category_link( $category->term_id ) );
            $category_name = esc_html( $category->name );
        ?>

        <?php
            echo '<li><a href="'. esc_url($category_link) .'">' . esc_html($category_name) . '</a></li>';

        };?>

        </ul>
        </div>
        </div>
        </div>
    </div>
    <?php
    }
endif;



/*
-------------------------------------------------------------------------------------------------------
    Add Excerpt To Pages
-------------------------------------------------------------------------------------------------------
*/

/**
 * Add excerpt to pages.
 */
function minimal_page_excerpts() {
    add_post_type_support( 'page', 'excerpt' );
}



/**
 * Register custom fonts.
 */
function minimalmag_fonts_url() {
    $fonts_url = '';

    $poppins = _x( 'on', 'Poppins font: on or off', 'minimal-magazine' );

    if ( 'off' !== $poppins ) {
        $font_families = array();

        $font_families[] = 'Poppins:300,300i,400,400i,500,500i,600,600i,700,700i,800,800i,900,900i';

        $query_args = array(
            'family' => urlencode( implode( '|', $font_families ) ),
            'subset' => urlencode( 'latin,latin-ext' ),
        );

        $fonts_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
    }

    return esc_url_raw( $fonts_url );
}

function minimalmag_resource_hints( $urls, $relation_type ) {
    if ( wp_style_is( 'minimal-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
        $urls[] = array(
            'href' => 'https://fonts.gstatic.com',
            'crossorigin',
        );
    }

    return $urls;
}
add_filter( 'wp_resource_hints', 'minimalmag_resource_hints', 10, 2 );