/**
 * customizer.js
 *
 * Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Theme Customizer preview reload changes asynchronously.
 */
(function ($) {

	var style = $( '.site-title a' ),
		accent_color_background = $('.main-navigation li a:before,.menu-toggle,.post-meta__tag__item a'),
		accent_color_text 		= $('.single.post-meta,.single.post-meta a,.comment-reply-link,.comment__author,.blog-post__meta .post-meta__time,.post-meta__author,.comment-edit-link'),
		menu_color 				= $('.main-navigation a,.main-navigation ul ul a'),
		other_color 			= $('.hamburger-inner,.hamburger-inner::before,.hamburger-inner::after,.hamburger__site-title,.main-navigation ul ul'),
		button_color_background = $('.comment-form input[type=submit],.site-search form input[type=submit],.button--secondary'),
		button_color_text 		= $('.button--secondary a,.comment-form input[type=submit]');



	// Site title
	wp.customize('blogname', function (value) {
		value.bind( function (to) {
			$('.site-title a').text( to );
		} );
	} );

	// Site Description
	wp.customize('blogdescription', function (value) {
		value.bind(function(to) {
			$( '.site-description' ).text( to );
		} );
	} );

/*--------------------------------------------------------------
## Color
--------------------------------------------------------------*/

	// Header text color.
	wp.customize('header_textcolor', function (value) {
		value.bind( function(to){
			if ( 'blank' === to ) {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'rect(1px, 1px, 1px, 1px)',
					'position': 'absolute'
				} );
			} else {
				$( '.site-title a, .site-description' ).css( {
					'clip': 'auto',
					'position': 'relative'
				} );
				$( '.site-title a, .site-description' ).css( {
					'color': to
				} );
			}
		} );
	} );

	//Header Background Color
	wp.customize( 'customization[header_background_color]', function( value ) {
		value.bind( function( newval ) {
			$('.site-header').css('background-color', newval );
		} );
	} );


	//Widget Background Color
	wp.customize( 'customization[widgets_background_color]', function( value ) {
		value.bind( function( newval ) {
			$('#secondary .widget').css('background-color', newval );
		} );
	} );



	// Footer Background Color
	wp.customize( 'customization[footer_background_color]', function( value ) {
		value.bind( function( newval ) {
			$('.site-footer').css('background-color', newval );
		} );
	} );

	// Site Body Text Color
	wp.customize( 'customization[body_text_color]', function( value ) {
		value.bind( function( newval ) {
			$('body').css('color', newval );
		} );
	} );


	// Menu Text Color
	wp.customize( 'customization[menu_text_color]', function( value ) {
		value.bind( function( newval ) {
			menu_color.css('color', newval );
		} );
	} );


	// Other Color
	wp.customize( 'customization[minimal_primary_color]', function( value ) {
		value.bind( function( newval ) {
			$('.scrollToTop').css('color', newval );
		} );
	} );

	// Other Color Background
	wp.customize( 'customization[minimal_primary_color]', function( value ) {
		value.bind( function( newval ) {
			other_color.css('background-color', newval );
		} );
	} );


	//Accent meta Color Background
	wp.customize( 'customization[minimal_accent_color]', function( value ) {
		value.bind( function( newval ) {
			accent_color_background.css('background-color', newval );
		} );
	} );

	//Accent meta Color Text
	wp.customize( 'customization[minimal_accent_color]', function( value ) {
		value.bind( function( newval ) {
			accent_color_text.css('color', newval );
		} );
	} );


	// Button Background Color
	wp.customize( 'customization[button_background_color]', function( value ) {
		value.bind( function( newval ) {
			button_color_background.css('background-color', newval );
		} );
	} );

	// Button Text Color
	wp.customize( 'customization[button_text_color]', function( value ) {
		value.bind( function( newval ) {
			button_color_text.css('color', newval );
		} );
	} );
	// Link Text Color
	wp.customize( 'customization[link_text_color]', function( value ) {
		value.bind( function( newval ) {
			$('a').css('color', newval );
		} );
	} );
	// Link Hover Color
	wp.customize( 'customization[link_hover_color]', function( value ) {
		value.bind( function( newval ) {
			$('a:hover').css('color', newval );
		} );
	} );




	// Front Page Blog Section Background Color
	wp.customize( 'customization[minimal_blogposts_background_color]', function( value ) {
		value.bind( function( newval ) {
			$('.front-blog').css('background-color', newval );
		} );
	} );

	// Home Latest Articles Background Color
	wp.customize( 'customization[home_latest_article_background_color]', function( value ) {
		value.bind( function( newval ) {
			$('.home-recent').css('background-color', newval );
		} );
	} );

	// Home Latest Articles Box Color
	wp.customize( 'customization[home_latest_article_box_color]', function( value ) {
		value.bind( function( newval ) {
			$('.recent-info').css('background-color', newval );
		} );
	} );

	// Home Latest Articles Background Color
	wp.customize( 'customization[home_featured_article_background_color]', function( value ) {
		value.bind( function( newval ) {
			$('.posts-slider').css('background-color', newval );
		} );
	} );

	// Home Latest Articles Box Color
	wp.customize( 'customization[home_featured_article_box_color]', function( value ) {
		value.bind( function( newval ) {
			$('.story-content').css('background-color', newval );
		} );
	} );
/*--------------------------------------------------------------
## Font Size
--------------------------------------------------------------*/

	// Body Font Size
	wp.customize( 'customization[minimal_body_font_size]', function( value ) {
		value.bind( function( newval ) {
			$('body').css('font-size', newval + 'px');
		} );
	} );

	// Menu Font Size
	wp.customize( 'customization[minimal_menu_font_size]', function( value ) {
		value.bind( function( newval ) {
			$('.menu-item a,.page-numbers a,.page-numbers span').css('font-size', newval + 'px');
		} );
	} );



	// Title Alignment Widget
	wp.customize( 'customization[minimal_widget_title_alignment]', function( value ) {
		value.bind( function( newval ) {
			$('.widget-title').css('text-align', newval );
		} );
	} );

/*--------------------------------------------------------------
## Layout & Positioning
--------------------------------------------------------------*/

	 // Website Width
     wp.customize( 'customization[minimal_website_width]', function( value ) {
        value.bind( function( to ) {
            $( '.website-width' ).css( 'width', to + '%' );
        } );
    });

	// Menu Position
	wp.customize( 'customization[minimal_menu_position]', function( value ) {
		value.bind( function( newval ) {
			$('.nav-menu').css('text-align', newval );
		} );
	} );




/*--------------------------------------------------------------
## Text
--------------------------------------------------------------*/

	// Text Field Content
	wp.customize('customization[minimal_copyright_text]', function (value) {
		value.bind( function (to) {
			$('.footer__copyright').text( to );
		} );
	} );

} )( jQuery );